"use strict";
/**
 * Copyright 2021 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.toRadians = exports.toDegrees = exports.sanitizeDegrees = exports.differenceDegrees = exports.lerp = exports.clamp = exports.signum = void 0;
/**
 * @return input < 0? -1. input = 0? 0. input > 0? 1.
 */
function signum(input) {
    if (input < 0) {
        return -1;
    }
    else if (input === 0) {
        return 0;
    }
    else {
        return 1;
    }
}
exports.signum = signum;
/**
 * Ensure min <= input <= max
 */
function clamp(min, max, input) {
    return Math.min(Math.max(input, min), max);
}
exports.clamp = clamp;
/**
 * Linearly interpolate from start to stop, by amount (0.0 <= amount <= 1.0)
 */
function lerp(start, stop, amount) {
    return (1.0 - amount) * start + amount * stop;
}
exports.lerp = lerp;
/**
 * Determine the shortest angle between two angles, measured in degrees.
 */
function differenceDegrees(a, b) {
    return 180.0 - Math.abs(Math.abs(a - b) - 180.0);
}
exports.differenceDegrees = differenceDegrees;
/**
 * Ensure 0 <= degrees < 360
 */
function sanitizeDegrees(degrees) {
    if (degrees < 0) {
        return (degrees % 360) + 360;
    }
    else if (degrees >= 360.0) {
        return degrees % 360;
    }
    else {
        return degrees;
    }
}
exports.sanitizeDegrees = sanitizeDegrees;
/**
 * Convert radians to degrees.
 */
function toDegrees(radians) {
    return (radians * 180.0) / Math.PI;
}
exports.toDegrees = toDegrees;
/**
 * Convert degrees to radians.
 */
function toRadians(degrees) {
    return (degrees / 180.0) * Math.PI;
}
exports.toRadians = toRadians;
